@@ -71,9 +71,7 @@ class MyProblem(Problem):
         )
 
     def _evaluate(self, x: List[int], out, *args, **kwargs):
-        out["F"] = np.column_stack(
-            self.evaluator.fitness(tuple(x))
-        )
+        out["F"] = np.column_stack(self.evaluator.fitness(x))
 
     def __is_power_of_2(self, n) -> int:
         return 0 if (n & (n - 1) == 0) and (n != 0) else 1
@@ -110,7 +108,11 @@ def optimize(
         )
     else:
         res = minimize(
-            problem, algorithm, seed=1, save_history=True, verbose=True,
+            problem,
+            algorithm,
+            seed=1,
+            save_history=True,
+            verbose=True,
         )
     with open("objs.pkl", "wb") as f:
         pickle.dump([res, algorithm], f)
